# コントリビューター行動規範

## 私たちの誓い

私たちは、メンバー、貢献者、リーダーとして、年齢、体型、目に見えるまたは目に見えない障害、民族性、性的特徴、性自認および表現、経験のレベル、教育、社会経済的地位、国籍、外見、人種、宗教、または性的指向や性自認に関わらず、すべての人にとってコミュニティへの参加が嫌がらせのない体験となることを誓います。

私たちは、オープンで歓迎的で多様性に富み、包括的で健全なコミュニティに貢献する方法で行動し、交流することを誓います。

## 私たちの基準

私たちのコミュニティにとってポジティブな環境を築く行動の例には、以下のようなものがあります：

* 他の人々に対して共感と思いやりを示すこと
* 異なる意見、視点、経験を尊重すること
* 建設的なフィードバックを与え、優雅に受け入れること
* 責任を受け入れ、私たちのミスによって影響を受けた人々に謝罪し、その経験から学ぶこと

* 個人としてだけでなく、コミュニティ全体にとって最善であることに焦点を当てる

許容できない行動の例には以下が含まれます：

* 性的な表現やイメージの使用、およびあらゆる種類の性的な関心やアプローチ

* トローリング、侮辱的または中傷的なコメント、個人または政治的な攻撃
* 公的または私的なハラスメント
* 明示的な許可なしに、物理的またはメールアドレスなどの他人の個人情報を公開すること

* 専門的な環境において不適切と合理的に考えられるその他の行為

## 施行責任

コミュニティリーダーは、許容される行動基準を明確にし、それを執行する責任があります。不適切、脅威的、攻撃的、または有害と判断される行動に対しては、適切かつ公正な是正措置を講じます。

コミュニティリーダーには、この行動規範に沿わないコメント、コミット、コード、Wiki編集、Issue、その他の貢献を削除、編集、または拒否する権利と責任があります。また、必要に応じてモデレーション決定の理由を説明します。

## スコープ

この行動規範は、すべてのコミュニティスペース内で適用され、また個人が公式にコミュニティを代表して公共の場で行動する場合にも適用されます。  
私たちのコミュニティを代表する例としては、公式メールアドレスの使用、公式ソーシャルメディアアカウントからの投稿、オンラインまたはオフラインイベントでの任命された代表者としての行動などが含まれます。

## 強制実行

虐待的、骚扰的、またはその他の容認できない行為の事例は、執行を担当するコミュニティリーダーに aw@funstory.ai まで報告することができます。  
すべての苦情は迅速かつ公平に審査・調査されます。  

すべてのコミュニティリーダーは、いかなる事件の報告者のプライバシーとセキュリティを尊重する義務があります。

## 施行ガイドライン

コミュニティリーダーは、この行動規範に違反すると判断した行為に対して、以下のコミュニティ影響ガイドラインに従って結果を決定します:

### 1. 修正

**コミュニティへの影響**: 不適切な言語の使用や、コミュニティにおいて非専門的または歓迎されないと見なされるその他の行動。

**結果**: コミュニティリーダーからの私的な書面による警告。違反の性質と、その行動が不適切であった理由についての説明が提供されます。公的な謝罪が求められる場合があります。

### 2. 警告

**コミュニティへの影響**: 単一のインシデントまたは一連の行動による違反。

**結果**: 継続的な行動に対する警告と結果。特定の期間、関係者との関わりを持たないこと。これには、行動規範を執行する人々との未承諾の関わりも含まれます。コミュニティスペースだけでなく、ソーシャルメディアなどの外部チャネルでの関わりも避ける必要があります。これらの条件に違反した場合、一時的または恒久的な追放につながる可能性があります。

### 3. 一時的な利用停止

**コミュニティへの影響**: コミュニティ基準に対する重大な違反、持続的な不適切な行動を含みます。

**結果**: 指定された期間、コミュニティとのあらゆる種類の相互作用または公開コミュニケーションから一時的に禁止されます。この期間中、関係者との公開または非公開の相互作用、行動規範を施行する人々との未承諾の相互作用は許可されません。これらの条件に違反すると、永久追放につながる可能性があります。

### 4. 永久追放

**コミュニティへの影響**: コミュニティ基準の違反パターンを示す行為。これには、持続的な不適切な行動、個人に対する嫌がらせ、または特定のグループに対する攻撃や中傷が含まれます。

**結果**: コミュニティ内でのあらゆる公開的な関与からの永久追放。

## 帰属

この行動規範は、[Contributor Covenant][homepage]のバージョン2.0を基に作成されており、
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html で閲覧可能です。

コミュニティ影響ガイドラインは、[Mozillaの行動規範実施ラダー](https://github.com/mozilla/diversity)に触発されました。

[homepage]: https://www.contributor-covenant.org

この行動規範に関するよくある質問への回答は、https://www.contributor-covenant.org/faq のFAQをご覧ください。翻訳は https://www.contributor-covenant.org/translations で利用可能です。

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>